OiRA

# Arbeidsomstandigheden en verzuim.

## Medewerkers ontvangen voorlichting en instructie over het veilig en gezond uitvoeren van hun werk

⚠U heeft 'nee' ingevuld bij bovenstaande risico.

De werkgever moet ervoor zorgen dat de medewerkers doeltreffend worden ingelicht over de te verrichten werkzaamheden en daaraan verbonden risico's, alsmede de maatregelen die er op gericht zijn deze risico's te voorkomen of te beperken.

Doeltreffend betekent in dit geval niet eenmalig maar structureel (d.w.z. met bepaalde regelmaat herhaald), toegespitst op de praktijk en actueel. Bedenk hierbij dat ook aandacht moet worden besteed aan de instructie vaan nieuwe medewerkers.

#### Wet- en regelgeving

### Wettelijk kader (Arbowet art.8 lid 1 en Arbobesluit art.5.5)

Licht medewerkers regelmatig voor over de risico's van het werk. Het verzorgen van voorlichting is nodig om medewerkers bewust te maken van het belang van een goede werkhouding. Enkele werkzaamheden waarbij de houding erg belangrijk is:het dragen van dienbladen; uitserveren; voorovergebogen werken bij koken en schoonmaken; boven de macht roeren; tilwerkzaamheden. (Arbowet art.8 lid 1 en Arbobesluit art.5.5)

Hoe groot is de kans op dit risico? Klein Gemiddeld Groot
Hoe vaak wordt men blootgesteld aan dit risico? Bijna nooit Regelmatig Voortdurend
Wat is het effect? Letsel zonder verzuim Letsel met verzuim Blijvende gezondheidsschade

Niet alle bureaus zijn in hoogte verstelbaar en vallen binnen de 74 en 76 cm.

1. Voorbereiding
2. Inventarisatie
3. Evaluatie
   1. 1 Arbobeleid in de onderneming
   2. 3 Bedrijfshulpverlening.
   3. 4 Inrichting Arbeidsplaatsen.
      1. 4.1 Onderhoud gebouwen, verlichting en klimaat.
      2. 4.2 Kantoorinrichting.
         1. 4.2.2 Medewerkers die werken met beeldschermen (beeldschermarbeid) worden voorgelicht over de risico's.
         2. 4.2.3 Printer en kopieermachines staan op voldoende afstand van de medewerkers.
         3. 4.2.6 Alle bureaus zijn goed in- of verstelbaar.
         4. 4.2.8 Medewerkers worden in de gelegenheid gesteld voor aanvang van de werkzaamheden en op gezette tijden onderzoek van het gezichtsvermogen en de ogen te ondergaan.
         5. 4.2.9 De beeldschermwerkplek is ingesteld op de medewerker die er gebruik van maakt.
      3. 4.8 Arbeidsmiddelen/hijsmiddelen.
   4. 5 Bijzondere risico's.
4. Plan van aanpak
5. Rapport

Geproduceerd door EU-OSHA | Over